summaryrefslogtreecommitdiff
path: root/src/xfns.c
diff options
context:
space:
mode:
authorFabián Ezequiel Gallina <fgallina@gnu.org>2015-01-28 00:59:34 -0300
committerFabián Ezequiel Gallina <fgallina@gnu.org>2015-01-28 00:59:34 -0300
commitd7a89815b6d69c3b1793d34bcad8bf0aa21d48c8 (patch)
tree6ac62b66bd5386355c96551da34416036cf279b7 /src/xfns.c
parent3a8b7013042adae3c27327a75662fd8e884d4896 (diff)
parentd279e6680842b872ae3aab1fb429b1879db50f7f (diff)
downloademacs-d7a89815b6d69c3b1793d34bcad8bf0aa21d48c8.tar.gz
Merge from origin/emacs-24
d279e66 Fix assertion violations in try_window_id (Bug#19511) 031eadc Fix dired quoting bug with "Hit`N`Hide" 5981b4b More doc fixes for bug#19502 -- make documentation less X-specific. 143516c src/emacs.c (syms_of_emacs) <system-configuration>: Doc fix. (Bug#19502)
Diffstat (limited to 'src/xfns.c')
-rw-r--r--src/xfns.c21
1 files changed, 16 insertions, 5 deletions
diff --git a/src/xfns.c b/src/xfns.c
index 9dd00868d7b..234915a8ce2 100644
--- a/src/xfns.c
+++ b/src/xfns.c
@@ -3542,10 +3542,15 @@ If omitted or nil, that stands for the selected frame's display. */)
}
DEFUN ("x-server-vendor", Fx_server_vendor, Sx_server_vendor, 0, 1, 0,
- doc: /* Return the "vendor ID" string of the X server of display TERMINAL.
+ doc: /* Return the "vendor ID" string of the GUI software on TERMINAL.
+
\(Labeling every distributor as a "vendor" embodies the false assumption
that operating systems cannot be developed and distributed noncommercially.)
The optional argument TERMINAL specifies which display to ask about.
+
+For GNU and Unix systems, this queries the X server software; for
+MS-Windows, this queries the OS.
+
TERMINAL should be a terminal object, a frame or a display name (a string).
If omitted or nil, that stands for the selected frame's display. */)
(Lisp_Object terminal)
@@ -3558,10 +3563,16 @@ If omitted or nil, that stands for the selected frame's display. */)
}
DEFUN ("x-server-version", Fx_server_version, Sx_server_version, 0, 1, 0,
- doc: /* Return the version numbers of the X server of display TERMINAL.
-The value is a list of three integers: the major and minor
-version numbers of the X Protocol in use, and the distributor-specific release
-number. See also the function `x-server-vendor'.
+ doc: /* Return the version numbers of the GUI software on TERMINAL.
+The value is a list of three integers specifying the version of the GUI
+software in use.
+
+For GNU and Unix system, the first 2 numbers are the version of the X
+Protocol used on TERMINAL and the 3rd number is the distributor-specific
+release number. For MS-Windows, the 3 numbers report the version and
+the build number of the OS.
+
+See also the function `x-server-vendor'.
The optional argument TERMINAL specifies which display to ask about.
TERMINAL should be a terminal object, a frame or a display name (a string).